@@ -10,21 +10,24 @@ HEADER_LABEL = "label"
 PROPERTIES   = "properties"
 CONSTRAINTS  = "constraints"
 
-class DescriptorGeneratorCSV(CSVParser.CSVParser):
 
-    '''
-        ApertureDB Descriptor Data loader.
+class DescriptorGeneratorCSV(CSVParser.CSVParser):
+    """
+        **ApertureDB Descriptor Data loader.**
+
+    .. note::
         Expects a csv file with the following columns, and a numpy
         array file "npz" for the descriptors:
 
-            filename,index,set,label,PROP_NAME_N,constraint_PROP1,connect_to
+            ``filename``, ``index``, ``set``, ``label``, ``PROP_NAME_N``, ``constraint_PROP1``, ``connect_to``
+
+    Example csv file::
 
-        Example csv file:
         filename,index,set,label,isTable,connect_VD:ROI,connect_VD:ROI@index
         /mnt/data/embeddings/kitchen.npz,0,kitchen,kitchen_table,True,has_descriptor,0
         /mnt/data/embeddings/dining_chairs.npz,1,dining_chairs,special_chair,False,has_descriptor,1
         ...
-    '''
+    """
 
     def __init__(self, filename):
 
@@ -33,8 +36,10 @@ class DescriptorGeneratorCSV(CSVParser.CSVParser):
         self.npy_arrays = {}
         self.has_label = False
 
-        self.props_keys       = [x for x in self.header[3:] if not x.startswith(CSVParser.CONTRAINTS_PREFIX) ]
-        self.constraints_keys = [x for x in self.header[3:] if x.startswith(CSVParser.CONTRAINTS_PREFIX) ]
+        self.props_keys       = [x for x in self.header[3:]
+                                 if not x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+        self.constraints_keys = [x for x in self.header[3:]
+                                 if x.startswith(CSVParser.CONTRAINTS_PREFIX)]
 
     def __getitem__(self, idx):
 
@@ -46,7 +51,8 @@ class DescriptorGeneratorCSV(CSVParser.CSVParser):
 
         if not desc_ok:
             print("Error loading descriptor: " + filename + ":" + index)
-            raise Exception("Error loading descriptor: " + filename + ":" + index)
+            raise Exception("Error loading descriptor: " +
+                            filename + ":" + index)
 
         data = {
             "descriptor_blob": descriptor,
@@ -74,7 +80,8 @@ class DescriptorGeneratorCSV(CSVParser.CSVParser):
         try:
             desc = self.npy_arrays[filename][index]
         except:
-            err_msg = "Cannot retrieve descriptor {} from {}".format(str(index), filename)
+            err_msg = "Cannot retrieve descriptor {} from {}".format(
+                str(index), filename)
             raise Exception(err_msg)
 
         return desc
@@ -102,27 +109,32 @@ class DescriptorGeneratorCSV(CSVParser.CSVParser):
             self.has_label = True
 
         if self.header[0] != HEADER_PATH:
-            raise Exception("Error with CSV file field: filename. Must be first field")
+            raise Exception(
+                "Error with CSV file field: filename. Must be first field")
         if self.header[1] != HEADER_INDEX:
-            raise Exception("Error with CSV file field: index. Must be second field")
+            raise Exception(
+                "Error with CSV file field: index. Must be second field")
         if self.header[2] != HEADER_SET:
-            raise Exception("Error with CSV file field: set. Must be third field")
+            raise Exception(
+                "Error with CSV file field: set. Must be third field")
+
 
 class DescriptorLoader(ParallelLoader.ParallelLoader):
+    """**ApertureDB Descriptor Loader.**
 
-    '''
-        ApertureDB Descriptor Loader.
+    This class is to be used in combination with a "generator".
+    The generator must be an iterable object that generated "descriptor_data"
+    elements.
+
+    Example::
 
-        This class is to be used in combination with a "generator".
-        The generator must be an iterable object that generated "descriptor_data"
-        elements:
             image_data = {
                 "label":       label,
                 "properties":  properties,
                 "constraints": constraints,
                 "descriptor_blob": (bytes),
             }
-    '''
+    """
 
     def __init__(self, db, dry_run=False):
 
